@@ -29,6 +29,7 @@
 namespace Solarus {
 
 constexpr int Music::nb_buffers;
+constexpr int Music::buffer_size;
 std::unique_ptr<SpcDecoder> Music::spc_decoder = nullptr;
 std::unique_ptr<ItDecoder> Music::it_decoder = nullptr;
 std::unique_ptr<OggDecoder> Music::ogg_decoder = nullptr;
@@ -155,7 +156,7 @@ void Music::set_volume(int volume) {
   volume = std::min(100, std::max(0, volume));
   Music::volume = volume / 100.0;
 
-  if (current_music != nullptr) {
+  if (current_music != nullptr && current_music->source != AL_NONE) {
     alSourcef(current_music->source, AL_GAIN, Music::volume);
   }
 }
@@ -355,6 +356,30 @@ void Music::stop_playing() {
   play(none, false);
 }
 
+/**
+ * \brief Pauses any music currently playing.
+ *
+ * The callback if any is not called.
+ */
+void Music::pause_playing() {
+
+  if (current_music != nullptr) {
+    current_music->set_paused(true);
+  }
+}
+
+/**
+ * \brief Resumes playing any music previously paused.
+ *
+ * The callback if any is not called.
+ */
+void Music::resume_playing() {
+
+  if (current_music != nullptr) {
+    current_music->set_paused(false);
+  }
+}
+
 /**
  * \brief Updates the music system.
  *
@@ -387,6 +412,11 @@ void Music::update() {
  */
 bool Music::update_playing() {
 
+  if (alcGetCurrentContext() == nullptr) {
+    // Device disconnected.
+    return true;
+  }
+
   // Get the empty buffers.
   ALint nb_empty;
   alGetSourcei(source, AL_BUFFERS_PROCESSED, &nb_empty);
@@ -400,15 +430,15 @@ bool Music::update_playing() {
     switch (format) {
 
       case SPC:
-        decode_spc(buffer, 16384);
+        decode_spc(buffer, buffer_size);
         break;
 
       case IT:
-        decode_it(buffer, 16384);
+        decode_it(buffer, buffer_size);
         break;
 
       case OGG:
-        decode_ogg(buffer, 16384);
+        decode_ogg(buffer, buffer_size);
         break;
 
       case NO_FORMAT:
@@ -431,6 +461,71 @@ bool Music::update_playing() {
   return status == AL_PLAYING;
 }
 
+/**
+ * \brief Notifies the music system that the audio device was disconnected.
+ */
+void Music::notify_device_disconnected_all() {
+
+  if (current_music != nullptr) {
+    current_music->notify_device_disconnected();
+  }
+}
+
+/**
+ * \brief Notifies this music system that the audio device was disconnected.
+ */
+void Music::notify_device_disconnected() {
+
+  // All sources and buffers are already destroyed by OpenAL at this point.
+  source = AL_NONE;
+  for (int i = 0; i < nb_buffers; ++i) {
+    buffers[i] = AL_NONE;
+  }
+}
+
+/**
+ * \brief Notifies the music system that an audio device was reconnected.
+ */
+void Music::notify_device_reconnected_all() {
+
+  if (current_music != nullptr) {
+    current_music->notify_device_reconnected();
+  }
+}
+
+void Music::notify_device_reconnected() {
+
+  if (buffers[0] == AL_NONE) {
+    // Recreate a source and buffers.
+    alGenBuffers(nb_buffers, buffers);
+    alGenSources(1, &source);
+    alSourcef(source, AL_GAIN, volume);
+
+    // Continue playing music.
+    // Buffer data that was already decoded to buffers before the
+    // disconnection is lost, so we actually skipped a short period of time.
+    for (int i = 0; i < nb_buffers; i++) {
+      ALuint buffer = buffers[i];
+      switch (format) {
+        case SPC:
+          decode_spc(buffer, buffer_size);
+          break;
+        case IT:
+          decode_it(buffer, buffer_size);
+          break;
+        case OGG:
+          decode_ogg(buffer, buffer_size);
+          break;
+        case NO_FORMAT:
+          Debug::die("Invalid music format");
+          break;
+      }
+      alSourceQueueBuffers(source, 1, &buffer);
+    }
+    alSourcePlay(source);
+  }
+}
+
 /**
  * \brief Decodes a chunk of SPC data into PCM data for the current music.
  * \param destination_buffer the destination buffer to write
@@ -536,7 +631,7 @@ bool Music::start() {
       spc_decoder->load((int16_t*) sound_buffer.data(), sound_buffer.size());
 
       for (int i = 0; i < nb_buffers; i++) {
-        decode_spc(buffers[i], 16384);
+        decode_spc(buffers[i], buffer_size);
       }
       break;
 
@@ -548,7 +643,7 @@ bool Music::start() {
       it_decoder->load(sound_buffer);
 
       for (int i = 0; i < nb_buffers; i++) {
-        decode_it(buffers[i], 16384);
+        decode_it(buffers[i], buffer_size);
       }
       break;
 
@@ -560,7 +655,7 @@ bool Music::start() {
       success = ogg_decoder->load(std::move(sound_buffer), this->loop);
       if (success) {
         for (int i = 0; i < nb_buffers; i++) {
-          decode_ogg(buffers[i], 16384);
+          decode_ogg(buffers[i], buffer_size);
         }
       }
       break;
@@ -615,7 +710,6 @@ void Music::stop() {
   for (int i = 0; i < nb_queued; i++) {
     alSourceUnqueueBuffers(source, 1, &buffer);
   }
-  alSourcei(source, AL_BUFFER, 0);
 
   // delete the source
   alDeleteSources(1, &source);
@@ -688,4 +782,3 @@ void Music::set_callback(const ScopedLuaRef& callback_ref) {
 }
 
 }
-
